@@ -15,14 +15,12 @@
  * along with jpegxl-rs.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#![cfg_attr(docsrs, doc(cfg(feature = "image")))]
-
 //! `image` crate integration
 
 use std::mem::MaybeUninit;
 
 use image::{DynamicImage, ImageBuffer};
-use jpegxl_sys::types::{JxlDataType, JxlPixelFormat};
+use jpegxl_sys::common::types::{JxlDataType, JxlPixelFormat};
 
 use crate::{
     common::PixelType,
@@ -174,7 +172,6 @@ mod tests {
     }
 
     #[test]
-    #[cfg(feature = "threads")]
     #[cfg_attr(coverage_nightly, coverage(off))]
     fn pixel_type() -> TestResult {
         let parallel_runner = ThreadsRunner::default();
